@@ -18,7 +18,7 @@
 
 #include "generator.h"
 #include "device.h"
-#include "debug.h"
+#include "kscreen_daemon_debug.h"
 
 #include <QDBusReply>
 #include <QDBusMessage>
@@ -41,7 +41,7 @@
     }
 #endif
 
-Generator* Generator::instance = 0;
+Generator* Generator::instance = nullptr;
 
 bool operator<(const QSize &s1, const QSize &s2)
 {
@@ -69,7 +69,7 @@ Generator::Generator()
 void Generator::destroy()
 {
     delete Generator::instance;
-    Generator::instance = 0;
+    Generator::instance = nullptr;
 }
 
 Generator::~Generator()
@@ -298,7 +298,6 @@ void Generator::cloneScreens(KScreen::OutputList &connectedOutputs)
     QSet<QSize> commonSizes;
     const QSize maxScreenSize  = m_currentConfig->screen()->maxSize();
 
-    QList<QSet<QSize>> modes;
     Q_FOREACH(const KScreen::OutputPtr &output, connectedOutputs) {
         QSet<QSize> modeSizes;
         Q_FOREACH(const KScreen::ModePtr &mode, output->modes()) {
@@ -626,7 +625,7 @@ KScreen::OutputPtr Generator::embeddedOutput(const KScreen::OutputList &outputs)
     return KScreen::OutputPtr();
 }
 
-bool Generator::isLaptop()
+bool Generator::isLaptop() const
 {
     if (m_forceLaptop) {
         return true;
@@ -638,7 +637,7 @@ bool Generator::isLaptop()
     return Device::self()->isLaptop();
 }
 
-bool Generator::isLidClosed()
+bool Generator::isLidClosed() const
 {
     if (m_forceLidClosed) {
         return true;
@@ -650,7 +649,7 @@ bool Generator::isLidClosed()
     return Device::self()->isLidClosed();
 }
 
-bool Generator::isDocked()
+bool Generator::isDocked() const
 {
     if (m_forceDocked) {
         return true;
